@@ -3,8 +3,9 @@ from health_check.plugins import plugin_dir
 
 
 class HealthCheckConfig(AppConfig):
-    name = 'heroku_connect.contrib.heroku_connect_health_check'
+    name = "heroku_connect.contrib.heroku_connect_health_check"
 
     def ready(self):
         from .backends import HerokuConnectHealthCheck
+
         plugin_dir.register(HerokuConnectHealthCheck)
